@@ -17,27 +17,27 @@
 #' \dontrun{db.reader('example.db', 'data/example.db', 'example')}
 db.reader <- function(data.file, filename, variable.name)
 {
-  require.package('RSQLite')
+  .require.package('RSQLite')
 
-  sqlite.driver <- dbDriver("SQLite")
-  connection <- dbConnect(sqlite.driver,
+  sqlite.driver <- DBI::dbDriver("SQLite")
+  connection <- DBI::dbConnect(sqlite.driver,
                           dbname = filename)
-  
-  tables <- dbListTables(connection)
+
+  tables <- DBI::dbListTables(connection)
   for (table in tables)
   {
     message(paste('  Loading table:', table))
-    
-    data.parcel <- dbReadTable(connection,
+
+    data.parcel <- DBI::dbReadTable(connection,
                                table,
                                row.names = NULL)
-    
+
     assign(clean.variable.name(table),
            data.parcel,
            envir = .TargetEnv)
   }
 
-  disconnect.success <- dbDisconnect(connection)
+  disconnect.success <- DBI::dbDisconnect(connection)
   if (! disconnect.success)
   {
     warning(paste('Unable to disconnect from database:', filename))
